@@ -6,7 +6,7 @@ from uuid6 import uuid7
 
 
 from .config import HtmlDisplayConfiguration
-from .models import PublishingActor
+from .database import PublishingActor
 
 
 @dataclass
@@ -28,7 +28,7 @@ class Publisher:
         url = (
             self.config.html_url_start(self.actor.actor)
             + self.actor.name
-            + "/"
+            + "/o/"
             + str(self.uuid)
         )
 
