@@ -6,7 +6,7 @@ import uuid
 from sqlalchemy import select
 from sqlalchemy.ext.asyncio import AsyncSession
 
-from cattle_grid.extensions.examples.html_display.models import PublishingActor
+from cattle_grid.extensions.examples.html_display.database import PublishingActor
 
 
 def new_name():
