@@ -1,6 +1,6 @@
 from uuid import UUID
 
-from .models import PublishingActor
+from .database import PublishingActor
 from .storage import object_for_name_and_uuid, publishing_actor_for_actor_id
 
 from .testing import *  # noqa
