@@ -22,6 +22,11 @@ class MethodInformationModel(BaseModel):
         description="""Description of the method""",
     )
 
+    replies: bool = Field(
+        default=False,
+        description="Indicates whether the method will reply on `receive.NAME.response.trigger` to the trigger event",
+    )
+
 
 class AddMethodInformationMessage(BaseModel):
     """Message to add method information through the exchange"""
